ccx -i acou4 
ccx -i acou5 
ccx -i acouquad 
ccx -i anipla2 
ccx -i anipla3 
ccx -i anipla4 
ccx -i anipla_nl_dy_exp 
ccx -i anipla_nl_dy_imp 
ccx -i anipla_nl_st 
ccx -i artery3 
ccx -i artery4 
ccx -i artery5 
ccx -i b31 
ccx -i ball 
ccx -i beam10psmooth 
ccx -i beam8pjc 
ccx -i beamcr3 
ccx -i beamcr4 
ccx -i beamexpdy1 
ccx -i beamf3 
ccx -i beamf 
ccx -i beamfrdread 
ccx -i beamfsms 
ccx -i beamhtfcnu 
ccx -i beamimpdy1 
ccx -i beamimpdy1nodirect 
ccx -i beamimpdy2 
ccx -i beamnldye20 
ccx -i beamnldye 
ccx -i beamnldyems 
ccx -i beamnldyeortho 
ccx -i beamnldy 
ccx -i beamnldynodirect 
ccx -i beamnldype 
ccx -i beamnldyp 
ccx -i beamp1rotate 
ccx -i beamp2 
ccx -i beamp3 
ccx -i beamp_ciarlet 
ccx -i beamperror 
ccx -i beamp 
ccx -i beamprb 
ccx -i beam_sens_freq_coord2 
ccx -i beam_sens_freq_coord3 
ccx -i beam_sens_ps13 
ccx -i beam_sens_stress_coord1_explicit 
ccx -i beam_sens_stress_coord1_implicit 
ccx -i beam_sens_stress_coord1 
ccx -i beam_sens_stress_coord2 
ccx -i beamt 
ccx -i beamwrite3 
ccx -i boxprofile2 
ccx -i boxprofile 
ccx -i changecontacttype1 
ccx -i changecontacttype2 
ccx -i changesolidsection 
ccx -i channeljoint1a 
ccx -i circ10pcent 
ccx -i circ10p 
ccx -i concretebeam 
ccx -i contact11 
ccx -i contact12 
ccx -i contact15 
ccx -i contact15lin 
ccx -i contact16 
ccx -i contact19 
ccx -i contact2 
ccx -i contactdeleteelement 
ccx -i contdamp1 
ccx -i contdamp2 
ccx -i coupling13 
ccx -i coupling14 
ccx -i cube2 
ccx -i cubef2f3 
ccx -i cubenewt 
ccx -i cyl 
ccx -i dashpot5 
ccx -i dashpot6 
ccx -i disconnect 
ccx -i dyncubeexp 
ccx -i dyncube 
ccx -i equrem1 
ccx -i equrem2 
ccx -i equrem3 
ccx -i equrem4 
ccx -i gap2 
ccx -i green1 
ccx -i impdyn 
ccx -i induction 
ccx -i largerot1 
ccx -i largerot2 
ccx -i largerot3 
ccx -i largerot4 
ccx -i largerot5 
ccx -i leifer1 
ccx -i leifer2 
ccx -i membrane1 
ccx -i membrane3 
ccx -i mohr1 
ccx -i mohr2 
ccx -i networkmpc2 
ccx -i oneel 
ccx -i oneeltruss 
ccx -i opt1dp 
ccx -i opt1 
ccx -i opt2 
ccx -i pendel 
ccx -i pipe2 
ccx -i planestrain2 
ccx -i planestrain 
ccx -i planestress3dsens 
ccx -i planestress3 
ccx -i planestress4 
ccx -i plate2dmass 
ccx -i plate2dpeeq 
ccx -i pret1 
ccx -i pret4 
ccx -i pret5 
ccx -i pret6 
ccx -i primaryair 
ccx -i section 
ccx -i segmentsmooth2 
ccx -i segmentsmooth 
ccx -i segmentunsmooth 
ccx -i sens3d 
ccx -i sensitivity_VII 
ccx -i shell1 
ccx -i shell3 
ccx -i shell5 
ccx -i shell6 
ccx -i shell6rot2 
ccx -i shell7 
ccx -i shell7rot2 
ccx -i shell7rot 
ccx -i simplebeam 
ccx -i simplebeampipe5 
ccx -i square 
ccx -i tempdiscon 
ccx -i testmortar 
ccx -i thermomech 
ccx -i truss2 
ccx -i truss 
ccx -i uprofile 
ccx -i zerocoeff 
ccx -i zerovel 

